
import { Suspense, lazy } from "react";
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { HelmetProvider } from 'react-helmet-async';

// Lazy load all pages except Index (keep Index for initial render)
import Index from "./pages/Index";
const Contact = lazy(() => import("./pages/Contact"));
const TermsOfService = lazy(() => import("./pages/TermsOfService"));
const PrivacyPolicy = lazy(() => import("./pages/PrivacyPolicy"));
const PaymentSuccess = lazy(() => import("./pages/PaymentSuccess"));
const PaymentCancelled = lazy(() => import("./pages/PaymentCancelled"));
const Sitemap = lazy(() => import("./pages/Sitemap"));
const NotFound = lazy(() => import("./pages/NotFound"));
const CelebritySoulmateMatch = lazy(() => import("./pages/CelebritySoulmateMatch"));
const FreeTools = lazy(() => import("./pages/FreeTools"));
const CompatibilityCalculator = lazy(() => import("./pages/CompatibilityCalculator"));
const LoveFortuneTeller = lazy(() => import("./pages/LoveFortuneTeller"));
const SoulmateNameGenerator = lazy(() => import("./pages/SoulmateNameGenerator"));
const NameBasedLoveCalculator = lazy(() => import("./pages/NameBasedLoveCalculator"));
const SoulPathNumerology = lazy(() => import("./pages/SoulPathNumerology"));
const FullMoonTimer = lazy(() => import("./pages/FullMoonTimer"));
const AngelNumberOfTheDay = lazy(() => import("./pages/AngelNumberOfTheDay"));
const DailyLoveTarot = lazy(() => import("./pages/DailyLoveTarot"));
const HeartSecureAttachmentQuiz = lazy(() => import("./pages/HeartSecureAttachmentQuiz"));
const LoveLanguageQuiz = lazy(() => import("./pages/LoveLanguageQuiz"));

const queryClient = new QueryClient();

// Loading fallback component
const PageLoader = () => (
  <div className="min-h-screen bg-white flex items-center justify-center">
    <div className="text-center">
      <div className="w-8 h-8 border-4 border-raspberry border-t-transparent rounded-full animate-spin mx-auto mb-4"></div>
      <p className="text-charcoal">Loading...</p>
    </div>
  </div>
);

const App = () => (
  <QueryClientProvider client={queryClient}>
    <HelmetProvider>
      <TooltipProvider>
        <Toaster />
        <Sonner />
        <BrowserRouter>
          <Suspense fallback={<PageLoader />}>
            <Routes>
              <Route path="/" element={<Index />} />
              <Route path="/free-tools" element={<FreeTools />} />
              <Route path="/contact" element={<Contact />} />
              <Route path="/terms" element={<TermsOfService />} />
              <Route path="/privacy" element={<PrivacyPolicy />} />
              <Route path="/payment-success" element={<PaymentSuccess />} />
              <Route path="/payment-cancelled" element={<PaymentCancelled />} />
              <Route path="/celebrity-soulmate-match" element={<CelebritySoulmateMatch />} />
              <Route path="/compatibility-calculator" element={<CompatibilityCalculator />} />
              <Route path="/love-fortune-teller" element={<LoveFortuneTeller />} />
              <Route path="/soulmate-name-generator" element={<SoulmateNameGenerator />} />
              <Route path="/name-love-calculator" element={<NameBasedLoveCalculator />} />
              <Route path="/soul-path-numerology" element={<SoulPathNumerology />} />
              <Route path="/full-moon-timer" element={<FullMoonTimer />} />
              <Route path="/angel-number-of-the-day" element={<AngelNumberOfTheDay />} />
              <Route path="/daily-love-tarot" element={<DailyLoveTarot />} />
              <Route path="/heartsecure-attachment-quiz" element={<HeartSecureAttachmentQuiz />} />
              <Route path="/love-language-quiz" element={<LoveLanguageQuiz />} />
              <Route path="/sitemap.xml" element={<Sitemap />} />
              <Route path="*" element={<NotFound />} />
            </Routes>
          </Suspense>
        </BrowserRouter>
      </TooltipProvider>
    </HelmetProvider>
  </QueryClientProvider>
);

export default App;
